@@ -13,7 +13,8 @@ from qottoauth.models import (
     Role,
     Authorization,
     Matching,
-    Cookie, Identity,
+    Cookie,
+    Identity,
 )
 
 __all__ = [
